/**
 * Copyright (C) 2003-2005 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */

package sync4j.syncclient.common;

import java.util.Calendar;

import java.io.IOException;
import java.io.File;

import com.funambol.commons.io.FileTools;

/**
 * This class supports
 * define log methods
 *
 * @author  Fabio Maggi @ Funambol
 * @version $Id: Logger.java,v 1.1.2.1 2005/01/27 11:00:57 fabius Exp $
 *
 **/

public class Logger {

    //-------------------------------------------------------------- Constants

    public static final int       LEVEL_NONE               = 0          ;
    public static final int       LEVEL_INFO               = 1          ;
    public static final int       LEVEL_DEBUG              = 2          ;

    public static final String    PROP_NONE                = "none"     ;
    public static final String    PROP_INFO                = "info"     ;
    public static final String    PROP_DEBUG               = "debug"    ;

    private static final String   DEFAULT_LOG_FILE_NAME    = "sync.log" ;
    private static final int      DEFAULT_LOGGER_LEVEL     = LEVEL_INFO ;
    private static final boolean  DEFAULT_CONSOLE_ENABLE   = true       ;

    private static final String
        MSG_LOG_START=
        "# SyncClient API J2SE Log"                                       ;

    //------------------------------------------------------------ Private data

    private static int      loggerLevel    = 0     ;
    private static boolean  consoleEnable  = false ;
    private static File     logFile        = null  ;

    //------------------------------------------------------------ Public methods

    /**
     * set logger level
     *
     * @param level
     **/
    public static void setLoggerLevel(int level)         {
        loggerLevel = level;
    }

    /**
     * set logger level
     *
     * @param level
     **/
    public static void setLoggerLevel(String level)      {

        if (PROP_NONE.equals         (level)) {
            loggerLevel = LEVEL_NONE  ;
        } else if (PROP_INFO.equals  (level)) {
            loggerLevel = LEVEL_INFO  ;
        } else if (PROP_DEBUG.equals (level)) {
            loggerLevel = LEVEL_DEBUG ;
        }

    }

    /**
     * set default logger level
     **/
    public static void setDefaultLoggerLevel()           {
        loggerLevel = DEFAULT_LOGGER_LEVEL;
    }

    /**
     * set log file
     *
     * @param fileName
     **/
    public static void setLogFile(String fileName)       {
        logFile = new File(fileName);
    }

    /**
     * set log file by default log file name
     **/
    public static void setDefaultLogFile()               {
        logFile = new File(DEFAULT_LOG_FILE_NAME);
    }

    /**
     * set enable / disable log console
     *
     * @param enable
     **/
    public static void setEnableConsole(boolean enable)  {
        consoleEnable = enable;
    }

    /**
     * set DEFAULT enable console
     **/
    public static void setDefaultEnableConsole()         {
        consoleEnable = DEFAULT_CONSOLE_ENABLE;
    }

    /**
     * check log level
     *
     * @param level
     * @return <p>true</p> if level is setting
     **/
    public boolean isLoggable(int level) {
        if (loggerLevel == level) {
            return true  ;
        } else {
            return false ;
        }
    }

    /**
     * Init log file
     **/
    public void init()
    throws IOException {

        try {

            String initMsg = null;

            initMsg = getDateTime(false) +
                      " - "              +
                      MSG_LOG_START      +
                      "\n"               ;

            FileTools.writeTextFile(logFile, initMsg, false);

            if (consoleEnable) {
                System.out.println(initMsg);
            }

        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    /**
     * Logs a string.at info level
     *
     * @param text the string to be logged
     **/
    public void info(String text) {

        try {

            text = getDateTime(true) +
                   " [INFO] - "      +
                   text              +
                   "\n"              ;

            FileTools.writeTextFile(logFile, text, true);

            if (consoleEnable) {
                System.out.print(text);
            }

        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    /**
     * Logs a string at debug level.
     *
     * @param text the string to be logged
     **/
    public void debug(String text) {

        try {

            text = getDateTime(true) +
                   " [DEBUG] - "     +
                   text              +
                   "\n"              ;

            FileTools.writeTextFile(logFile, text, true);

            if (consoleEnable) {
                System.out.print(text);
            }

        } catch (Exception e) {
            e.printStackTrace();
        }

    }


    //---------------------------------------------------------- Private methods

    /**
     *
     * Return now in "[YYYY-MM-DD hh:mm:ss:SSS]"
     * format
     *
     **/
    private String getDateTime(boolean onlyTime) {

        Calendar date        = null ;

        String   year        = null ;
        String   month       = null ;
        String   day         = null ;
        String   hour        = null ;
        String   minute      = null ;
        String   second      = null ;
        String   millisecond = null ;

        String   time        = null ;
        String   dateTime    = null ;

        date = Calendar.getInstance();

        date.setTimeInMillis(System.currentTimeMillis());

        year        = String.valueOf( date.get(Calendar.YEAR         ) ) ;
        month       = String.valueOf( date.get(Calendar.MONTH        ) ) ;
        day         = String.valueOf( date.get(Calendar.DAY_OF_MONTH ) ) ;
        hour        = String.valueOf( date.get(Calendar.HOUR_OF_DAY  ) ) ;
        minute      = String.valueOf( date.get(Calendar.MINUTE       ) ) ;
        second      = String.valueOf( date.get(Calendar.SECOND       ) ) ;
        millisecond = String.valueOf( date.get(Calendar.MILLISECOND  ) ) ;

        if (month.length()       == 1 )        {
            month       = "0"  + month;
        }
        if (day.length()         == 1 )        {
            day         = "0"  + day;
        }
        if (hour.length()        == 1 )        {
            hour        = "0"  + hour;
        }
        if (minute.length()      == 1 )        {
            minute      = "0"  + minute;
        }
        if (second.length()      == 1 )        {
            second      = "0"  + second;
        }
        if (millisecond.length() == 1 )        {
            millisecond = "00" + millisecond;
        }
        if (millisecond.length() == 2 )        {
            millisecond = "0"  + millisecond;
        }

        time =  hour         +
                ":"          +
                minute       +
                ":"          +
                second       +
                ":"          +
                millisecond  ;

        if (onlyTime) {
            return time;
        }

        dateTime =  year         +
                    "-"          +
                    month        +
                    "-"          +
                    day          +
                    " "          +
                    time         ;

        return dateTime;

    }

}